@@ -41,20 +41,6 @@
 #include <dirent.h>
 #include <limits.h>
 
-/* Quick hack so I can mark strings */
-
-#ifdef _ 
-#warning "_ already defined"
-#else
-#define _(x) x
-#endif
-
-#ifdef N_ 
-#warning "N_ already defined"
-#else
-#define N_(x) x
-#endif
-
 /*
  * Overview
  * 
@@ -152,69 +138,69 @@ static void       xs_destroy   (XMLSource* source);
  */
 
  /* shutdown() is a BSD libc function */
-static void          x_shutdown        (GConfError** err);
+static void          x_shutdown        (GError** err);
 
 static GConfSource*  resolve_address (const gchar* address,
-                                      GConfError** err);
+                                      GError** err);
 
 static void          lock            (GConfSource* source,
-                                      GConfError** err);
+                                      GError** err);
 
 static void          unlock          (GConfSource* source,
-                                      GConfError** err);
+                                      GError** err);
 
 static gboolean     readable         (GConfSource* source,
                                       const gchar* key,
-                                      GConfError** err);
+                                      GError** err);
 
-static gboolean     writeable        (GConfSource* source,
+static gboolean     writable        (GConfSource* source,
                                       const gchar* key,
-                                      GConfError** err);
+                                      GError** err);
 
 static GConfValue*   query_value     (GConfSource* source,
                                       const gchar* key,
                                       const gchar** locales,
                                       gchar** schema_name,
-                                      GConfError** err);
+                                      GError** err);
 
 static GConfMetaInfo*query_metainfo  (GConfSource* source,
                                       const gchar* key,
-                                      GConfError** err);
+                                      GError** err);
 
 static void          set_value       (GConfSource* source,
                                       const gchar* key,
                                       GConfValue* value,
-                                      GConfError** err);
+                                      GError** err);
 
 static GSList*       all_entries    (GConfSource* source,
                                      const gchar* dir,
                                      const gchar** locales,
-                                     GConfError** err);
+                                     GError** err);
 
 static GSList*       all_subdirs     (GConfSource* source,
                                       const gchar* dir,
-                                      GConfError** err);
+                                      GError** err);
 
 static void          unset_value     (GConfSource* source,
                                       const gchar* key,
                                       const gchar* locale,
-                                      GConfError** err);
+                                      GError** err);
 
 static gboolean      dir_exists      (GConfSource *source,
                                       const gchar *dir,
-                                      GConfError** err);
+                                      GError** err);
 
 static void          remove_dir      (GConfSource* source,
                                       const gchar* dir,
-                                      GConfError** err);
+                                      GError** err);
 
 static void          set_schema      (GConfSource* source,
                                       const gchar* key,
                                       const gchar* schema_key,
-                                      GConfError** err);
+                                      GError** err);
 
 static gboolean      sync_all        (GConfSource* source,
-                                      GConfError** err);
+                                      GError** err);
 
 static void          destroy_source  (GConfSource* source);
 
@@ -226,7 +212,7 @@ static GConfBackendVTable xml_vtable = {
   lock,
   unlock,
   readable,
-  writeable,
+  writable,
   query_value,
   query_metainfo,
   set_value,
@@ -242,14 +228,14 @@ static GConfBackendVTable xml_vtable = {
 };
 
 static void          
-x_shutdown (GConfError** err)
+x_shutdown (GError** err)
 {
   gconf_log(GCL_INFO, _("Unloading XML backend module."));
 }
 
 static void
 lock (GConfSource* source,
-      GConfError** err)
+      GError** err)
 {
   
 
@@ -257,7 +243,7 @@ lock (GConfSource* source,
 
 static void
 unlock (GConfSource* source,
-        GConfError** err)
+        GError** err)
 {
 
 
@@ -266,23 +252,23 @@ unlock (GConfSource* source,
 static gboolean
 readable (GConfSource* source,
           const gchar* key,
-          GConfError** err)
+          GError** err)
 {
 
   return TRUE;
 }
 
 static gboolean
-writeable (GConfSource* source,
+writable (GConfSource* source,
            const gchar* key,
-           GConfError** err)
+           GError** err)
 {
 
   return TRUE;
 }
 
 static GConfSource*  
-resolve_address (const gchar* address, GConfError** err)
+resolve_address (const gchar* address, GError** err)
 {
   gchar* root_dir;
   XMLSource* xsource;
@@ -331,8 +317,8 @@ resolve_address (const gchar* address, GConfError** err)
     }
   
   {
-    /* See if we're writeable */
-    gboolean writeable = FALSE;
+    /* See if we're writable */
+    gboolean writable = FALSE;
     int fd;
     gchar* testfile;
 
@@ -342,7 +328,7 @@ resolve_address (const gchar* address, GConfError** err)
 
     if (fd >= 0)
       {
-        writeable = TRUE;
+        writable = TRUE;
         close(fd);
       }
         
@@ -350,17 +336,17 @@ resolve_address (const gchar* address, GConfError** err)
 
     g_free(testfile);
     
-    if (writeable)
+    if (writable)
       flags |= GCONF_SOURCE_ALL_WRITEABLE;
 
-    /* We only do locking if it's writeable,
+    /* We only do locking if it's writable,
        which is sort of broken but close enough
     */
-    if (writeable)
+    if (writable)
       {
         gchar* lockdir;
 
-        lockdir = gconf_concat_key_and_dir(root_dir, "%gconf-xml-backend.lock");
+        lockdir = gconf_concat_dir_and_key(root_dir, "%gconf-xml-backend.lock");
         
         lock = gconf_get_lock(lockdir, err);
 
@@ -424,12 +410,12 @@ query_value (GConfSource* source,
              const gchar* key,
              const gchar** locales,
              gchar** schema_name,
-             GConfError** err)
+             GError** err)
 {
   XMLSource* xs = (XMLSource*)source;
   gchar* parent;
   Dir* dir;
-  GConfError* error = NULL;
+  GError* error = NULL;
 
   parent = gconf_key_directory(key);
   
@@ -443,8 +429,8 @@ query_value (GConfSource* source,
      problem, since some errors may be added that need reporting. */
   if (error != NULL)
     {
-      gconf_log(GCL_WARNING, error->str);
-      gconf_error_destroy(error);
+      gconf_log(GCL_WARNING, error->message);
+      g_error_free(error);
       error = NULL;
     }
   
@@ -463,8 +449,8 @@ query_value (GConfSource* source,
       /* perhaps we should be reporting this error... */
       if (error != NULL)
         {
-          gconf_log(GCL_WARNING, error->str);
-          gconf_error_destroy(error);
+          gconf_log(GCL_WARNING, error->message);
+          g_error_free(error);
           error = NULL;
         }
       
@@ -476,7 +462,7 @@ query_value (GConfSource* source,
 
 static GConfMetaInfo*
 query_metainfo  (GConfSource* source, const gchar* key,
-                 GConfError** err)
+                 GError** err)
 {
   XMLSource* xs = (XMLSource*)source;
   gchar* parent;
@@ -500,7 +486,7 @@ query_metainfo  (GConfSource* source, const gchar* key,
 
 static void          
 set_value (GConfSource* source, const gchar* key, GConfValue* value,
-           GConfError** err)
+           GError** err)
 {
   XMLSource* xs = (XMLSource*)source;
   Dir* dir;
@@ -538,7 +524,7 @@ static GSList*
 all_entries    (GConfSource* source,
                 const gchar* key,
                 const gchar** locales,
-                GConfError** err)
+                GError** err)
 {
   XMLSource* xs = (XMLSource*)source;
   Dir* dir;
@@ -554,24 +540,24 @@ all_entries    (GConfSource* source,
 static GSList*
 all_subdirs     (GConfSource* source,
                  const gchar* key,
-                 GConfError** err)
+                 GError** err)
 {
   Dir* dir;
   XMLSource* xs = (XMLSource*)source;
 
-  dir = cache_lookup(xs->cache, key, FALSE, err);
+  dir = cache_lookup (xs->cache, key, FALSE, err);
   
   if (dir == NULL)
     return NULL;
   else
-    return dir_all_subdirs(dir, err);
+    return dir_all_subdirs (dir, err);
 }
 
 static void          
 unset_value     (GConfSource* source,
                  const gchar* key,
                  const gchar* locale,
-                 GConfError** err)
+                 GError** err)
 {
   XMLSource* xs = (XMLSource*)source;
   Dir* dir;
@@ -600,7 +586,7 @@ unset_value     (GConfSource* source,
 static gboolean
 dir_exists      (GConfSource*source,
                  const gchar* key,
-                 GConfError** err)
+                 GError** err)
 {
   XMLSource *xs = (XMLSource*)source;
   Dir* dir;
@@ -613,7 +599,7 @@ dir_exists      (GConfSource*source,
 static void          
 remove_dir      (GConfSource* source,
                  const gchar* key,
-                 GConfError** err)
+                 GError** err)
 {
   XMLSource* xs = (XMLSource*)source;
   Dir* dir;
@@ -632,7 +618,7 @@ static void
 set_schema      (GConfSource* source,
                  const gchar* key,
                  const gchar* schema_key,
-                 GConfError** err)
+                 GError** err)
 {
   XMLSource* xs = (XMLSource*)source;
 
@@ -664,7 +650,7 @@ set_schema      (GConfSource* source,
 
 static gboolean      
 sync_all        (GConfSource* source,
-                 GConfError** err)
+                 GError** err)
 {
   XMLSource* xs = (XMLSource*)source;
 
@@ -748,7 +734,7 @@ xs_new       (const gchar* root_dir, guint dir_mode, guint file_mode, GConfLock*
 static void
 xs_destroy   (XMLSource* xs)
 {
-  GConfError* error = NULL;
+  GError* error = NULL;
   
   g_return_if_fail(xs != NULL);
 
@@ -757,8 +743,8 @@ xs_destroy   (XMLSource* xs)
   if (xs->lock != NULL && !gconf_release_lock(xs->lock, &error))
     {
       gconf_log(GCL_ERR, _("Failed to give up lock on XML dir `%s': %s"),
-                xs->root_dir, error->str);
-      gconf_error_destroy(error);
+                xs->root_dir, error->message);
+      g_error_free(error);
       error = NULL;
     }
   
